typing
------

Support for type hints.

.. autosummary::

    cbgen.typing.Genotype
    cbgen.typing.Partition
    cbgen.typing.Variants

.. autoclass:: cbgen.typing.Genotype
   :members:

.. autoclass:: cbgen.typing.Partition
   :members:

.. autoclass:: cbgen.typing.Variants
   :members:
